<?php

require_once get_template_directory() . '/includes/loader.php';

add_action( 'after_setup_theme', 'alquran_setup_theme' );
add_action( 'after_setup_theme', 'alquran_load_default_hooks' );


function alquran_setup_theme() {

	load_theme_textdomain( 'alquran', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-header' );
	add_theme_support( 'custom-background' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'woocommerce' ); 
	
	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'align-wide' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'responsive-embeds' );
	add_theme_support( 'wp-block-styles' );
    
	// Set the default content width.
	$GLOBALS['content_width'] = 525;
	
	/*---------- Register image sizes ----------*/
	
	//Register image sizes
	add_image_size( 'alquran_370x430', 370, 430, true ); //alquran_370x430 Project Carousel
	add_image_size( 'alquran_480x541', 480, 541, true ); //alquran_480x541 Project Carousel
	add_image_size( 'alquran_99x99', 99, 99, true ); //alquran_99x99 Testimonials Carousel
	add_image_size( 'alquran_370x227', 370, 227, true ); //alquran_370x227 Blog Grid
	add_image_size( 'alquran_370x433', 370, 433, true ); //alquran_370x433 Team Grid
	add_image_size( 'alquran_370x205', 370, 205, true ); //alquran_370x433 Team Grid
	add_image_size( 'alquran_370x264', 370, 264, true ); //alquran_370x264 Team Grid
	
	
	//Single pages image size
	add_image_size( 'alquran_542x612', 542, 612, true ); //alquran_542x612 Team Single
	add_image_size( 'alquran_770x400', 770, 400, true ); //alquran_770x400 Blog Single
	
	
	
	/*---------- Register image sizes ends ----------*/
	
	
	
	// This theme uses wp_nav_menu() in two locations.
	register_nav_menus( array(
		'main_menu' => esc_html__( 'Main Menu', 'alquran' ),
		'footer_menu' => esc_html__( 'Footer Menu', 'alquran' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Add theme support for Custom Logo.
	add_theme_support( 'custom-logo', array(
		'width'      => 250,
		'height'     => 250,
		'flex-width' => true,
	) );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, and column width.
 	 */
	add_editor_style();
	add_action( 'admin_init', 'alquran_admin_init', 2000000 );
}

/**
 * [alquran_admin_init]
 *
 * @param  array $data [description]
 *
 * @return [type]       [description]
 */


function alquran_admin_init() {
	remove_action( 'admin_notices', array( 'ReduxFramework', '_admin_notices' ), 99 );
}

/*---------- Sidebar settings ----------*/

/**
 * [alquran_widgets_init]
 *
 * @param  array $data [description]
 *
 * @return [type]       [description]
 */
function alquran_widgets_init() {

	global $wp_registered_sidebars;
	$theme_options = get_theme_mod( 'alquran' . '_options-mods' );
	register_sidebar( array(
		'name'          => esc_html__( 'Default Sidebar', 'alquran' ),
		'id'            => 'default-sidebar',
		'description'   => esc_html__( 'Widgets in this area will be shown on the right-hand side.', 'alquran' ),
		'before_widget' => '<div id="%1$s" class="widget sidebar-widget %2$s"><div class="widget-content">',
		'after_widget'  => '</div></div>',
		'before_title'  => '<div class="sidebar-title"><h4>',
		'after_title'   => '</h4></div>',
	) );
	register_sidebar(array(
		'name' => esc_html__('Footer Widget', 'alquran'),
		'id' => 'footer-sidebar',
		'description' => esc_html__('Widgets in this area will be shown in Footer Area.', 'alquran'),
		'before_widget'=>'<div class="footer-column col-xl-3 col-lg-6 col-md-6 col-sm-12 wow fadeInUp" data-wow-delay="100ms"><div id="%1$s" class="footer-widget %2$s">',
		'after_widget'=>'</div></div>',
		'before_title' => '<h4 class="footer-title">',
		'after_title' => '</h4>'
	));
	if ( class_exists( '\Elementor\Plugin' )){
		register_sidebar(array(
		  'name' => esc_html__( 'Blog Listing', 'alquran' ),
		  'id' => 'blog-sidebar',
		  'description' => esc_html__( 'Widgets in this area will be shown on the right-hand side.', 'alquran' ),
		  'before_widget'=>'<div id="%1$s" class="widget sidebar-widget %2$s"><div class="widget-content">',
		  'after_widget'=>'</div></div>',
		  'before_title' => '<div class="sidebar-title"><h4>',
		  'after_title' => '</h4></div>'
		));
	}
	if ( ! is_object( alquran_WSH() ) ) {
		return;
	}

	$sidebars = alquran_set( $theme_options, 'custom_sidebar_name' );

	foreach ( array_filter( (array) $sidebars ) as $sidebar ) {

		if ( alquran_set( $sidebar, 'topcopy' ) ) {
			continue;
		}

		$name = $sidebar;
		if ( ! $name ) {
			continue;
		}
		$slug = str_replace( ' ', '_', $name );

		register_sidebar( array(
			'name'          => $name,
			'id'            => sanitize_title( $slug ),
			'before_widget' => '<div id="%1$s" class="%2$s widget sidebar-widget">',
			'after_widget'  => '</div>',
			'before_title'  => '<div class="widget-title"><h3>',
			'after_title'   => '</h3></div>',
		) );
	}

	update_option( 'wp_registered_sidebars', $wp_registered_sidebars );
}

add_action( 'widgets_init', 'alquran_widgets_init' );

/*---------- Sidebar settings ends ----------*/

/*---------- Gutenberg settings ----------*/

function alquran_gutenberg_editor_palette_styles() {
    add_theme_support( 'editor-color-palette', array(
        array(
            'name' => esc_html__( 'strong yellow', 'alquran' ),
            'slug' => 'strong-yellow',
            'color' => '#f7bd00',
        ),
        array(
            'name' => esc_html__( 'strong white', 'alquran' ),
            'slug' => 'strong-white',
            'color' => '#fff',
        ),
		array(
            'name' => esc_html__( 'light black', 'alquran' ),
            'slug' => 'light-black',
            'color' => '#242424',
        ),
        array(
            'name' => esc_html__( 'very light gray', 'alquran' ),
            'slug' => 'very-light-gray',
            'color' => '#797979',
        ),
        array(
            'name' => esc_html__( 'very dark black', 'alquran' ),
            'slug' => 'very-dark-black',
            'color' => '#000000',
        ),
    ) );
	
	add_theme_support( 'editor-font-sizes', array(
		array(
			'name' => esc_html__( 'Small', 'alquran' ),
			'size' => 10,
			'slug' => 'small'
		),
		array(
			'name' => esc_html__( 'Normal', 'alquran' ),
			'size' => 15,
			'slug' => 'normal'
		),
		array(
			'name' => esc_html__( 'Large', 'alquran' ),
			'size' => 24,
			'slug' => 'large'
		),
		array(
			'name' => esc_html__( 'Huge', 'alquran' ),
			'size' => 36,
			'slug' => 'huge'
		)
	) );
	
}
add_action( 'after_setup_theme', 'alquran_gutenberg_editor_palette_styles' );

/*---------- Gutenberg settings ends ----------*/

/*---------- Enqueue Styles and Scripts ----------*/

function alquran_enqueue_scripts() {
	$options = alquran_WSH()->option();
	$header_meta = get_post_meta( get_the_ID(), 'header_style_settings');
	$header_option = $options->get( 'header_style_settings' );
	$header = ( $header_meta ) ? $header_meta['0'] : $header_option;
		
	if( $options->get( 'main_color_scheme' ) ){
		$maincolor = str_replace( '#', '' , $options->get( 'main_color_scheme' ));
		
	}else{
		$maincolor = str_replace( '#', '' , '#1C8E5A' );
	}
	if( $options->get( 'main_color_scheme_two' ) ){
		$maincolor_two = str_replace( '#', '' , $options->get( 'main_color_scheme_two' ));
		
	}else{
		$maincolor_two = str_replace( '#', '' , '#161515' );
	}
	if( $options->get( 'secondary_color_scheme' ) ){
		$secondcolor = str_replace( '#', '' , $options->get( 'secondary_color_scheme' ));
	}
	else{
		$secondcolor = str_replace( '#', '' , '#FFD050' );	
	}
	
    //styles
    wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.css' );
	wp_enqueue_style( 'alquran-global', get_template_directory_uri() . '/assets/css/global.css' );
	wp_enqueue_style( 'alquran-header', get_template_directory_uri() . '/assets/css/header.css' );
	wp_enqueue_style( 'alquran-footer', get_template_directory_uri() . '/assets/css/footer.css');
	wp_enqueue_style( 'animate', get_template_directory_uri() . '/assets/css/animate.css' );
	wp_enqueue_style( 'preloader', get_template_directory_uri() . '/assets/css/preloader.css' );
	wp_enqueue_style( 'jquery-ui', get_template_directory_uri() . '/assets/css/jquery-ui.css' );
	wp_enqueue_style( 'swiper', get_template_directory_uri() . '/assets/css/swiper.min.css' );	
	wp_enqueue_style( 'alquran-font-awesome', get_template_directory_uri() . '/assets/css/font-awesome.css' );	
	wp_enqueue_style( 'custom-animate', get_template_directory_uri() . '/assets/css/custom-animate.css' );
	wp_enqueue_style( 'magnific-popup', get_template_directory_uri() . '/assets/css/magnific-popup.css' );
	wp_enqueue_style( 'flaticon_afbd3404a2e1104832d0', get_template_directory_uri() . '/assets/css/flaticon_afbd3404a2e1104832d0.css' );
	wp_enqueue_style( 'odometer-theme-default', get_template_directory_uri() . '/assets/css/odometer-theme-default.css' );	
	wp_enqueue_style( 'jquery-bootstrap-touchspin', get_template_directory_uri() . '/assets/css/jquery.bootstrap-touchspin.css' );	
	wp_enqueue_style( 'alquran-main', get_stylesheet_uri() );
	wp_enqueue_style( 'alquran-main-style', get_template_directory_uri() . '/assets/css/style.css' );
	wp_enqueue_style( 'alquran-custom', get_template_directory_uri() . '/assets/css/custom.css' );
	wp_enqueue_style( 'alquran-woocommerce', get_template_directory_uri() . '/assets/css/woocommerce.css' );
	wp_enqueue_style( 'alquran-tut', get_template_directory_uri() . '/assets/css/tut.css' );
	wp_enqueue_style( 'alquran-gutenberg', get_template_directory_uri() . '/assets/css/gutenberg.css' );
	wp_enqueue_style( 'alquran-responsive', get_template_directory_uri() . '/assets/css/responsive.css' );
	wp_enqueue_style( 'alquran-main-color-scheme', get_template_directory_uri() . '/assets/css/color.php?main_color='.$maincolor.'&main_color_two='.$maincolor_two.'&second_color='.$secondcolor.'');

    //scripts
	wp_enqueue_script( 'jquery-ui-core');
	wp_enqueue_script( 'popper', get_template_directory_uri().'/assets/js/popper.min.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'bootstrap', get_template_directory_uri().'/assets/js/bootstrap.min.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'appear', get_template_directory_uri().'/assets/js/appear.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'parallax', get_template_directory_uri().'/assets/js/parallax.min.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'tilt-jquery', get_template_directory_uri().'/assets/js/tilt.jquery.min.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'jquery-paroller', get_template_directory_uri().'/assets/js/jquery.paroller.min.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'wow', get_template_directory_uri().'/assets/js/wow.js', array( 'jquery' ), '2.1.2', true );	
	wp_enqueue_script( 'jarallax', get_template_directory_uri().'/assets/js/jarallax.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'swiper', get_template_directory_uri().'/assets/js/swiper.min.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'odometer', get_template_directory_uri().'/assets/js/backtotop.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'backtotop', get_template_directory_uri().'/assets/js/odometer.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'parallax-scroll', get_template_directory_uri().'/assets/js/parallax-scroll.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'gsap', get_template_directory_uri().'/assets/js/gsap.min.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'splittext', get_template_directory_uri().'/assets/js/SplitText.min.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'scrolltrigger', get_template_directory_uri().'/assets/js/ScrollTrigger.min.js"', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'scrollToplugin', get_template_directory_uri().'/assets/js/ScrollToPlugin.min.js', array( 'jquery' ), '2.1.2', true );	
	wp_enqueue_script( 'scrollsmoother', get_template_directory_uri().'/assets/js/ScrollSmoother.min.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'magnific-popup', get_template_directory_uri().'/assets/js/magnific-popup.min.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'jquery-countdown', get_template_directory_uri().'/assets/js/jquery.countdown.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'nav-tool', get_template_directory_uri().'/assets/js/nav-tool.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'jquery-ui', get_template_directory_uri().'/assets/js/jquery-ui.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'element-in-view', get_template_directory_uri().'/assets/js/element-in-view.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'alquran-main-script', get_template_directory_uri().'/assets/js/script.js', array(), false, true );
	
	if( is_singular() ) wp_enqueue_script('comment-reply');
}
add_action( 'wp_enqueue_scripts', 'alquran_enqueue_scripts' );

/*---------- Enqueue styles and scripts ends ----------*/

/*---------- Google fonts ----------*/

function alquran_fonts_url() {
    $fonts_url = '';

    // Define font families with proper Google Fonts CSS2 format
    $font_families = array(
        'family=Lexend:wght@300;400;500;600;700;800;900&display=swap',
        'family=Inter:wght@300;400;500;600;700;800;900&display=swap',
        'family=Abril+Fatface&display=swap',
    );

    // Allow external modifications via filter
    $font_families = apply_filters( 'alquran_font_families', $font_families );

    // Build the Google Fonts URL
    if ( ! empty( $font_families ) ) {
        $protocol  = is_ssl() ? 'https' : 'http';
        $fonts_url = $protocol . '://fonts.googleapis.com/css2?' . implode( '&', $font_families );
    }

    return esc_url_raw( $fonts_url );
}


function alquran_theme_styles() {
    wp_enqueue_style( 'alquran-theme-fonts', alquran_fonts_url(), array(), null );
}

add_action( 'wp_enqueue_scripts', 'alquran_theme_styles' );
add_action( 'admin_enqueue_scripts', 'alquran_theme_styles' );

/*---------- Google fonts ends ----------*/

/*---------- More functions ----------*/

// 1) alquran_set function

/**
 * [alquran_set description]
 *
 * @param  array $data [description]
 *
 * @return [type]       [description]
 */
if ( ! function_exists( 'alquran_set' ) ) {
	function alquran_set( $var, $key, $def = '' ) {

		if ( is_object( $var ) && isset( $var->$key ) ) {
			return $var->$key;
		} elseif ( is_array( $var ) && isset( $var[ $key ] ) ) {
			return $var[ $key ];
		} elseif ( $def ) {
			return $def;
		} else {
			return false;
		}
	}
}


//Contact Form 7 List
function get_contact_form_7_list()
{
	$contact_forms = array();
	$cf7 = get_posts( 'post_type="wpcf7_contact_form"&numberposts=-1' );
	if (!empty($cf7)) {
		foreach ($cf7 as $cform) {
			if (isset($cform)) {
				if (isset($cform->ID) && isset($cform->post_title)) {
					$contact_forms[$cform->ID] = $cform->post_title;
				}
			}
		}
	}
    return $contact_forms;
}

// 2) alquran_add_editor_styles function

function alquran_add_editor_styles() {
    add_editor_style( 'editor-style.css' );
}
add_action( 'admin_init', 'alquran_add_editor_styles' );

// 3) Add specific CSS class by filter body class.

$options = alquran_WSH()->option(); 
if( alquran_set($options, 'boxed_wrapper') ){

add_filter( 'body_class', function( $classes ) {
    $classes[] = 'boxed_wrapper';
    return $classes;
} );
}

function alquran_register_block_patterns() {
    register_block_pattern(
        'alquran/custom-pattern-1',
        array(
            'title'       => __('Custom Pattern 1', 'alquran'),
            'description' => __('Description of Custom Pattern 1.', 'alquran'),
            'content'     => '<!-- Your block pattern content here -->',
            'categories'  => array('text'),
            'keywords'    => array('pattern', 'layout', 'custom'),
        )
    );

    // Add more block patterns as needed
}
add_action('init', 'alquran_register_block_patterns');
function alquran_register_block_styles() {
    // Register custom block styles for specific blocks
    register_block_style(
        'core/paragraph',
        array(
            'name'         => 'alquran-custom-style-1',
            'label'        => __('Custom Style 1', 'alquran'),
            'style_handle' => 'alquran-custom-style-1-css', // Enqueue your custom style CSS
        )
    );

    // Add more custom block styles as needed
}
add_action('init', 'alquran_register_block_styles');